==> haskell-safesemaphore-0.10.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-safesemaphore.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: SafeSemaphore
version: 0.10.1
id: SafeSemaphore-0.10.1-9eHPbrSv26jFacOVow93bv
key: SafeSemaphore-0.10.1-9eHPbrSv26jFacOVow93bv
license: BSD3
maintainer: Chris Kuklewicz <haskell@list.mightyreason.com>
homepage: https://github.com/ChrisKuklewicz/SafeSemaphore
synopsis: Much safer replacement for QSemN, QSem, and SampleVar
description:
    This provides a much safer semaphore than the QSem, QSemN, SampleVar in base.
    Those base modules are not exception safe and can be broken by killThread.
    See <https://github.com/ChrisKuklewicz/SafeSemaphore> for more details.
category: Concurrency
author: Chris Kuklewicz <haskell@list.mightyreason.com>
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.FairRWLock Control.Concurrent.MSampleVar
    Control.Concurrent.MSem Control.Concurrent.MSemN
    Control.Concurrent.MSemN2 Control.Concurrent.SSem
    Control.Concurrent.STM.SSem
hidden-modules: Control.Concurrent.STM.SSemInternals
abi: 09b821aab91a6f02f6fabeea9f2031e1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/SafeSemaphore-0.10.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/SafeSemaphore-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/SafeSemaphore-0.10.1
hs-libraries: HSSafeSemaphore-0.10.1-9eHPbrSv26jFacOVow93bv
depends:
    base-4.10.1.0 containers-0.5.10.2
    stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad6bbd8e6ded9502ff897b95774cdf26
haddock-interfaces: /usr/share/doc/haskell-safesemaphore/html/SafeSemaphore.haddock
haddock-html: /usr/share/doc/haskell-safesemaphore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safesemaphore-0.10.1-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-safesemaphore.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: SafeSemaphore
version: 0.10.1
id: SafeSemaphore-0.10.1-Hsx9QD1iCOD1T9wxULdiEa
key: SafeSemaphore-0.10.1-Hsx9QD1iCOD1T9wxULdiEa
license: BSD-3-Clause
maintainer: Chris Kuklewicz <haskell@list.mightyreason.com>
author: Chris Kuklewicz <haskell@list.mightyreason.com>
homepage: https://github.com/ChrisKuklewicz/SafeSemaphore
synopsis: Much safer replacement for QSemN, QSem, and SampleVar
description:
    This provides a much safer semaphore than the QSem, QSemN, SampleVar in base.
    Those base modules are not exception safe and can be broken by killThread.
    See <https://github.com/ChrisKuklewicz/SafeSemaphore> for more details.
category: Concurrency
abi: 1ea5649ea5bb1880f1d3e46601deb2aa
exposed: True
exposed-modules:
    Control.Concurrent.FairRWLock Control.Concurrent.MSampleVar
    Control.Concurrent.MSem Control.Concurrent.MSemN
    Control.Concurrent.MSemN2 Control.Concurrent.SSem
    Control.Concurrent.STM.SSem
hidden-modules: Control.Concurrent.STM.SSemInternals
import-dirs: /usr/lib/ghc-8.4.3/site-local/SafeSemaphore-0.10.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/SafeSemaphore-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/SafeSemaphore-0.10.1
hs-libraries: HSSafeSemaphore-0.10.1-Hsx9QD1iCOD1T9wxULdiEa
depends:
    base-4.11.1.0 containers-0.5.11.0 stm-2.4.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
haddock-interfaces: /usr/share/doc/haskell-safesemaphore/html/SafeSemaphore.haddock
haddock-html: /usr/share/doc/haskell-safesemaphore/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
